# plone.classicui

The `plone.classicui` package provides all the templates and the code which is
necessary to render the classic Plone user interface.

The package contains page templates that were previously part of following packages,
like `plone.app.layout` and `plone.app.portlets`.
